Dir["test/**/test_*.rb"].each do |f|
  require File.expand_path(f)
end

skiplist = File.read("debian/ruby-tests.skip").split
exclude = "/" + skiplist.join("|") + "/"

ARGV.replace(["--exclude=#{exclude}"])
