if ENV["AUTOPKGTEST_TMP"]
  libs = "-Itest"
  ENV["RUBYGEMS_TEST_PATH"] = Dir.pwd + "/test/rubygems"
else
  libs = "-Itest:lib:bundler/lib"
end

task :default do
  ruby "-w", libs, "debian/test_runner.rb"
end
